rekha.plots.ScatterPlot
=======================

.. currentmodule:: rekha.plots

.. autoclass:: ScatterPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~ScatterPlot.add_annotation
      ~ScatterPlot.get_axes
      ~ScatterPlot.save
      ~ScatterPlot.save_all_formats
      ~ScatterPlot.show
      ~ScatterPlot.show_legend
      ~ScatterPlot.update_layout
   
   

   
   
   